Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(105)

Unified Diff: net/base/net_error_list.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rename all the things Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/net_error_list.h
diff --git a/net/base/net_error_list.h b/net/base/net_error_list.h
index 750f9ad1c9fec592eb28610a9df6f274819bf021..1f475003c1a63ccfc4a2134bf75b4ac58f112a3b 100644
--- a/net/base/net_error_list.h
+++ b/net/base/net_error_list.h
@@ -277,7 +277,7 @@ NET_ERROR(CLIENT_AUTH_CERT_TYPE_UNSUPPORTED, -151)
// Server requested one type of cert, then requested a different type while the
// first was still being generated.
-NET_ERROR(ORIGIN_BOUND_CERT_GENERATION_TYPE_MISMATCH, -152)
+NET_ERROR(SERVER_BOUND_CERT_GENERATION_TYPE_MISMATCH, -152)
wtc 2012/03/15 23:46:38 We probably should not rename these error codes be
mattm 2012/03/16 22:22:00 Done.
// Certificate error codes
//
@@ -618,8 +618,8 @@ NET_ERROR(PKCS12_IMPORT_UNSUPPORTED, -709)
// Key generation failed.
NET_ERROR(KEY_GENERATION_FAILED, -710)
-// Origin-bound certificate generation failed.
-NET_ERROR(ORIGIN_BOUND_CERT_GENERATION_FAILED, -711)
+// Server-bound certificate generation failed.
+NET_ERROR(SERVER_BOUND_CERT_GENERATION_FAILED, -711)
// Failure to export private key.
NET_ERROR(PRIVATE_KEY_EXPORT_FAILED, -712)

Powered by Google App Engine
This is Rietveld 408576698